aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorGerald Combs <gerald@wireshark.org>2012-01-25 01:16:36 +0000
committerGerald Combs <gerald@wireshark.org>2012-01-25 01:16:36 +0000
commit84151d47379256a25c7a050c2e284b59721ff558 (patch)
tree2c4d2592ea9d5f6a0a345ccb662f39f277bb1690
parent9a14284b5b09da5e404916ceabc40ea2a9688048 (diff)
Put back an "explicit" for now. I'm not sure it's necessary but Qt
Creator put it there as I recall. svn path=/trunk/; revision=40710
-rw-r--r--ui/qt/capture_file_dialog.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/ui/qt/capture_file_dialog.h b/ui/qt/capture_file_dialog.h
index bb6a350e80..34143b58f2 100644
--- a/ui/qt/capture_file_dialog.h
+++ b/ui/qt/capture_file_dialog.h
@@ -49,12 +49,12 @@ class CaptureFileDialog : public QFileDialog
// Yes, that's four implementations of the same window.
//
// If a plain native open file dialog is good enough we can just the static
// version of QFileDialog::getOpenFileName. (Commenting out Q_OBJECT below
// has the same effect.)
Q_OBJECT
public:
- CaptureFileDialog(QWidget *parent = 0);
+ explicit CaptureFileDialog(QWidget *parent = 0);
signals:
@@ -49,12 +49,12 @@ class CaptureFileDialog : public QFileDialog
//
// If a plain native open file dialog is good enough we can just the static
- // version of QFileDialog::getOpenFileName. (Commenting out Q_OBJECT below
- // has the same effect.)
+ // version of QFileDialog::getOpenFileName. (Commenting out Q_OBJECT and
+ // "explicit" below has the same effect.)
Q_OBJECT
public: